@@ -1,6 +1,6 @@
 from django.conf.urls.defaults import url, patterns
 
-from ajaximage.views import ajaxupload
+from ajaximage.views import ajaximage
 from ajaximage.forms import FileForm
 
 
